import { world, system, EquipmentSlot } from "@minecraft/server";

system.runInterval(() => {
    ticker();
}, 3);



const dimensions = ["overworld", "nether", "the_end"];
const bootLevelMap = {
    "nk:magnet_boots_1": 4,
    "nk:magnet_boots_2": 6,
    "nk:magnet_boots_3": 8
};

function ticker() {
    dimensions.forEach((dimension) => {
        const thisDimension = world.getDimension(dimension);
        const players = thisDimension && thisDimension.getPlayers();

        if (!thisDimension || !players) {
            return;
        }

        players.forEach((player) => {
            const equipmentInventory = player.getComponent("equippable");
            const equipment = equipmentInventory && equipmentInventory.getEquipment(EquipmentSlot.Feet);
            const magnet_level = equipment ? bootLevelMap[equipment.typeId] || 0 : 0;
            
            if (magnet_level > 0) {
                const items = thisDimension.getEntities({
                    location: player.location,
                    maxDistance: magnet_level,
                    type: "minecraft:item"
                });

                if (!items) {
                    world.sendMessage("!items")
                    return;
                }
                
                items.forEach((item) => {
                    const impulse = calculateImpulse(player.location, item.location, 0.3);
                    item.applyImpulse(impulse)
                });
            }
        });
    });
}

function calculateImpulse(player_location, item_location, speed) {
    // Calculate the direction vector from item2 to item1
    let direction = {
        x: player_location.x - item_location.x,
        y: player_location.y - item_location.y,
        z: player_location.z - item_location.z
    };

    // Normalize the direction vector (to get a unit vector)
    let magnitude = Math.sqrt(direction.x * direction.x + direction.y * direction.y + direction.z * direction.z);
    let unitDirection = {
        x: direction.x / magnitude,
        y: direction.y / magnitude,
        z: direction.z / magnitude
    };

    // Calculate the impulse needed to move at 'speed' towards item1
    let impulse = {
        x: unitDirection.x * speed,
        y: unitDirection.y * speed,
        z: unitDirection.z * speed
    };

    return impulse;
}
